@@ -35,7 +35,7 @@ import shlex
 import sys
 import time
 
-from kazoo.exceptions import NoNodeError, NotEmptyError
+from kazoo.exceptions import NoAuthError, NoNodeError, NotEmptyError
 
 from .acl import ACLReader
 from .augumented_client import AugumentedClient
@@ -66,9 +66,13 @@ class Shell(AugumentedCmd):
 
     def connected(f):
         def wrapped(self, args):
-          if self.connected:
-                return f(self, args)
-          print("Not connected.")
+            if not self.connected:
+                print("Not connected.")
+            else:
+                try:
+                    return f(self, args)
+                except NoAuthError as ex:
+                    print("Not authenticated.")
         return wrapped
 
     def check_path_exists(f):
@@ -113,6 +117,9 @@ example:
         except Exception as ex:
             print("Failed to set ACLs: %s. Error: %s" % (str(acls), str(ex)))
 
+    def complete_set_acls(self, cmd_param_text, full_cmd, start_idx, end_idx):
+        return self._complete_path(cmd_param_text, full_cmd)
+
     def help_set_acls(self):
         print("""
 sets ACLs for a given path.
@@ -128,6 +135,9 @@ example:
     def do_get_acls(self, params):
         print(self._zk.get_acls(params.path)[0])
 
+    def complete_get_acls(self, cmd_param_text, full_cmd, start_idx, end_idx):
+        return self._complete_path(cmd_param_text, full_cmd)
+
     def help_get_acls(self):
         print("""
 gets ACLs for a given path.
